
/**
 * 获取URL参数
 * @param {*} name 参数名
 * @returns 
 */
function getQueryString(name) {
    var reg = new RegExp("(^|&)" + name + "=([^&]*)(&|$)", "i");
    var r = window.location.search.substr(1).match(reg);
    if (r != null) return unescape(r[2]);
    return null;
}

/**
 * 接口请求 公共方法
 * @param {*} url 接口
 * @param {*} params 参数
 * @param {*} type 请求类型
 * @param {*} callback 回调函数
 */
function request(url, params, type, callback) {
    $.ajax({
        async: false, //采用异步的方式提交，true为同步
        type: type,
        // url: BASE_URL + url,
        url: url,
        data: params,
        // headers: {
        //     'Access-Control-Allow-Origin': "*"
        // },
        dataType: 'json',
        success: function (data) {
            callback(data)
        },
        error: function (err) {
            callback(err)
        }
    })
}

function setCookie(c_name, value, expiredays) {
    var exp = new Date();
    exp.setTime(exp.getTime() + 2 * 60 * 60 * 1000);
    document.cookie = c_name + "=" + escape(value) + ";expires=" + exp.toGMTString()
}

//取回cookie
function getCookie(c_name) {
    if (document.cookie.length > 0) {
        var c_start = document.cookie.indexOf(c_name + "=");
        var c_end;
        if (c_start != -1) {
            c_start = c_start + c_name.length + 1
            c_end = document.cookie.indexOf(";", c_start)
            if (c_end == -1) c_end = document.cookie.length
            return unescape(document.cookie.substring(c_start, c_end))
        }
    }
    return ""
}

function delCookie(key) {
    var date = new Date();
    date.setTime(date.getTime() - 1);
    var delValue = getCookie(key);
    if (!!delValue) {
        document.cookie = key + '=' + delValue + ';expires=' + date.toGMTString();
    }
}

function getURL(name) {
    var search = decodeURI(window.location.search);
    var reg = new RegExp("[?&]" + name + "=([^&]*)(&|$)", "i");
    var r = search.match(reg);
    if (r != null) return unescape(r[1]);
    return null;
};

function getToken() {
    let url = decodeURI(window.location.href)
    console.log(url)
    return getURL('token')
}

function is_wexin() {
    var ua = navigator.userAgent.toLowerCase();
    return ua.match(/MicroMessenger/i) == "micromessenger";
}

function is_IOS() {
    var ios = /\(i[^;]+;( U;)? CPU.+Mac OS X/i.test(navigator.userAgent);
    return ios;
}

function goBack() {
    window.history.back(-1);
}

function dateFormat(date, format) {
    let fmt = format || 'YYYY-mm-dd'
    let ret
    const opt = {
        "Y+": date.getFullYear().toString(), // 年
        "m+": (date.getMonth() + 1).toString(), // 月
        "d+": date.getDate().toString(), // 日
        "H+": date.getHours().toString(), // 时
        "M+": date.getMinutes().toString(), // 分
        "S+": date.getSeconds().toString() // 秒
        // 有其他格式化字符需求可以继续添加，必须转化成字符串
    }
    for (let k in opt) {
        ret = new RegExp("(" + k + ")").exec(fmt)
        if (ret) {
            fmt = fmt.replace(ret[1], (ret[1].length == 1) ? (opt[k]) : (opt[k].padStart(ret[1].length, "0")))
        }
    };
    return fmt
}

function base64Params(params) {
    let a = JSON.stringify(params)
    let b = Base64.encode(a)
    b = b.split('').reverse().join('')
    b = Base64.encode(b)
    return {
        data: b
    }
}

function base64Result(data) {
    let b = Base64.decode(data)
    b = b.split('').reverse().join('')
    b = Base64.decode(b)
    return b
}


// 
function debounce(fn, delay = 500, now = true) {
    let timer; // 维护一个 timer
    return function () {
        const _this = this; // 取debounce执行作用域的this
        const args = arguments;
        if (timer) {
            clearTimeout(timer);
        }
        const curNow = now ? !timer : false;
        timer = setTimeout(function () {
            timer = now ? null : fn.apply(_this, args);
        }, delay);

        if (curNow) fn.apply(_this, args); // 用apply指向调用debounce的对象，相当于_this.fn(args);
    };
}